#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor soup2%nil
%if "%{flavor}" == "soup2"
%define nsuffix -soup2
%define shlib   libgeocode-glib0
%define typelib typelib-1_0-GeocodeGlib-1_0
%else
%define shlib   libgeocode-glib-2-0
%define typelib typelib-1_0-GeocodeGlib-2_0

%endif

Name:           geocode-glib%{?nsuffix}
Version:        3.26.4
Release:        1.5
Summary:        Convenience library for the Yahoo! Place Finder APIs
License:        LGPL-2.0-or-later
Group:          Development/Libraries/GNOME
URL:            http://www.gnome.org/
Source0:        https://download.gnome.org/sources/geocode-glib/3.26/geocode-glib-%{version}.tar.xz
Source1:        baselibs.conf

BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.34
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.99.2
%if "%{flavor}" == "soup2"
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42
%else
BuildRequires:  pkgconfig(libsoup-3.0)
%endif

%description
The geocode-glib library is a convenience library for the Yahoo! Place
Finder APIs, as described at http://developer.yahoo.com/geo/placefinder/

The Place Finder web service allows to do geocoding (finding longitude
and latitude from an address), and reverse geocoding (finding an address
from coordinates).

%package -n %{shlib}
Summary:        Convenience library for the Yahoo! Place Finder APIs
# We require the icon set, which is shipped in the main package (in order
# to keep the library parallel installable, we require at least current version).
Group:          System/Libraries
# geocode-glib (without suffix) is built only once in the ""-flavor
Requires:       geocode-glib >= %{version}

%description -n %{shlib}
The geocode-glib library is a convenience library for the Yahoo! Place
Finder APIs, as described at http://developer.yahoo.com/geo/placefinder/

The Place Finder web service allows to do geocoding (finding longitude
and latitude from an address), and reverse geocoding (finding an address
from coordinates).

%package -n %{typelib}
Summary:        Introspection bindings for geocode-glib
Group:          System/Libraries

%description -n %{typelib}
The geocode-glib library is a convenience library for the Yahoo! Place
Finder APIs, as described at http://developer.yahoo.com/geo/placefinder/

The Place Finder web service allows to do geocoding (finding longitude
and latitude from an address), and reverse geocoding (finding an address
from coordinates).

This package provides the GObject Introspection bindings for the
geocode-glib library.

%package devel
Summary:        Development files for geocode-glib, a library for the Yahoo Place Finder APIs
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       %{typelib} = %{version}

%description devel
The geocode-glib library is a convenience library for the Yahoo! Place
Finder APIs, as described at http://developer.yahoo.com/geo/placefinder/

The Place Finder web service allows to do geocoding (finding longitude
and latitude from an address), and reverse geocoding (finding an address
from coordinates).

This package contains development files needed to develop with the
geocode-glib library.

%prep
%setup -q -n geocode-glib-%{version}

%build
# FIXME Please investigate if we should package installed-tests
%meson \
	-Denable-gtk-doc=true \
	-Denable-installed-tests=false \
%if "%{flavor}" == "soup2"
	-Dsoup2=true \
%else
	-Dsoup2=false \
%endif
	%{nil}
%meson_build

%install
%meson_install
# we package the icons as part of the ""-flavor package
%if "%{flavor}" != ""
rm -rf %{buildroot}%{_datadir}/icons/hicolor
%endif

%ldconfig_scriptlets -n %{shlib}

%if "%{flavor}" == ""
%files
%{_datadir}/icons/hicolor/
%endif

%files -n %{shlib}
%license COPYING.LIB
%doc AUTHORS NEWS README
%{_libdir}/*.so.*

%files -n %{typelib}
%{_libdir}/girepository-1.0/GeocodeGlib-*.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/geocode-glib*/
%{_datadir}/gir-1.0/*.gir
%{_includedir}/geocode-glib-*/
%{_libdir}/pkgconfig/geocode-glib-*.pc
%{_libdir}/*.so

%changelog
* Tue Aug  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.26.4:
  + This release includes a fix to a test data file not being
    installed, and a bug fix for a bug in the libsoup3 port.
* Thu Jun 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.26.3:
  + This release adds support for libsoup 3.x. To use the libsoup
    3.x build, applications will need to be adapted to look for the
    "-2.0" version of the API.
- Create multibuild flavor "soup2":
  + The soup2 flavor contains the packages we had so far, API 1.0
  + The ""-flavor is API 2.0, creating new subpackages
    libgeocode-glib-2-0 and typelib-1_0-GeocodeGlib-2_0.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.26.2:
  + Fix build exporting all the symbols.
  + Allow GIR generation when cross-compiling.
  + Allow unknown parameters inside geo: URL.
* Thu Mar 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.26.1:
  + Fix crashes caused by Nominatim server changes.
  + Fix warnings when building the API documentation.
* Wed Jun  6 2018 bjorn.lie@gmail.com
- Update to version 3.26.0:
  + Remove full build path from public headers so as to make the
    build more easily reproduceable.
- Drop geocode-glib-make-reproducible.patch: Fixed upstream.
- Drop hicolor-icon-theme BuildRequires: No longer needed.
* Sat Mar 17 2018 bjorn.lie@gmail.com
- Add geocode-glib-make-reproducible.patch: lib: Remove full build
  path from public headers. So as to make the build more easily
  reproducible.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Sep  8 2017 jengelh@inai.de
- Update descriptions and RPM groups.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.25.4.1:
  + Brown paperbag release to add news entry for 3.25.4.
- Changes from version 3.25.4:
  + Port to meson build system.
  + Drop autotools.
  + Provide a configure script for backwards compatibility.
  + Fix a warning from gcc 7.1.1.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Replace gnome-doc-utils-devel with gtk-doc BuildRequires and pass
  enable-gtk-doc=true to meson.
- Pass enable-installed-tests=false to meson, unsure if we should
  package these or not, default upstream is yes.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Stable bump only.
* Tue Feb  7 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Add g_autoptr cleanup functions.
  + Make code base const-correct.
  + Add backend abstraction.
  + Make unit-test base on offline mock backend.
  + Add support for multiple reverse results.
  + Add a user-agent property to override default user-agent.
  + Add equality functions to bbox/location/place.
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Fix build for uClibc.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Add icons to EXTRA_DIST.
  + Fix memleaks in query cache.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Add simple train stops and tram stops to place types.
  + Fix timestamp documentation.
* Sun Jan 31 2016 zaitor@opensuse.org
- Update to version 3.18.1:
  + Added a default User-Agent, based on GApplication ID if
    available. Nominatim’s usage policy requires a User-Agent, so
    we add one.
* Sun Sep 20 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + No changes, version bump only.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix compilation under MacOS X.
  + Make location timestamp writable on construction.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Update unit tests.
  + Add workaround for Nominatim boundingbox bug (bgo#749963).
  + Update project description.
  + Prettify Geo URI generation.
* Tue May 12 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Make error handling of reverse geocode more robust.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix bugs in reverse geocode.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + No changes.
* Tue Jan 13 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Derive the order of street name and street number from locale
    (GLIBC only).
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3.1:
  + Switch to https:// and fix the geocode cache.
  + Fix gtkdoc-check errors.
- Changes from version 3.15.3:
  + Add osm_type property to geocode place.
* Fri Nov 28 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Fix error handling in parsing of URIs.
  + Allow escape characters in URIs.
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf: provide multi-arch packages.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Add category and programming language to doap file.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Add types and icons for more amenity place types.
  + Fix memory leaks in geo uri handling.
  + Add description extension to geo uri.
  + Add cancellable check to all GSimpleAsyncResult.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Fix memory leaks in 'geo' URI parsing and testing.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + No changes since 3.11.92.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92.2:
  + Nano release to fix configure.ac hickup.
- Changes from version 3.11.92.1:
  + Fix typo in Nominatim search result attribute.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Add osm-id property to GeocodePlace.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Adapt to fixed behavior of json-glib. Without this we get a
    crash on parsing search results.
  + Require json-glib >= 0.99.2.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + API to expose bounding box of places from Nominatim.
  + Switch to jsonv2 format of Nominatim API to get all needed
    info.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 3.11.4.1:
  + A nano releaase to fix icon installation in 3.11.4.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Do not depend on intltool, use upstream gettext instead.
  + Check for libsoup not libsoup-gnome in Makefile.am.
  + Add parsing of geo URI to GeocodeLocation (RFC 5870).
  + Add altitude and CRS (Coordinate Reference System) property to
    GeocodeLocation.
  + Allow specifying a bounding-box search-area for GeocodeForward
    searches.
  + Replace the Nominatim place icons with place type derived
    icons, using the BSD licensed Maki point-of-interest icon set.
- Require geocode-glib from the library package in ordere to have
  the new icon set available to the library.
- Add hicolor-icon-theme BuildRequires: needed for the post/postun
  script macros.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Depend on json-glib >= 0.16.2 to avoid conflict w/ json-c.
  + Remove a now redundant workaround from a testcase.
  + Fix `make distcheck` against latest gtk-doc.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 0.99.4:
  + Fixes to gobject-introspection.
  + Version documentation installation directory.
  + Documentation build fixes.
  + Explicitly link to libm.
  + Fix a leak.
  + Sync GeocodeLocation with its copy in Geoclue.
  + Ensure country codes are always in upper-case.
  + Some cleanups.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 0.99.3:
  + Fix a crash in reverse geocoding API.
  + Expose place icons when available from Nominatim.
  + Make GeocodeReverse locale safe.
  + Fix build against latest gnome-common.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 0.99.2:
  + Make use of our new proxy to Nominatim at nominatim.gnome.org.
  + Better name/description for street numbers.
  + Fixes to build.
  + Drop all geoip code, which has been moved to Geoclue where it
    belongs.
  + Fix failing testcases.
- Drop pkgconfig(geoip) BuildRequires: no longer needed.
* Wed Jul 31 2013 dimstar@opensuse.org
- Update to version 0.99.1:
  + The library has almost been completey re-written since 0.99.0
    so too many changes to document here. Most notable changes
    however are:
  - Freeform geocoding, and reverse geocoding search API.
  - Search results are now locale aware.
  - We now use Nominatim instead of Yahoo Places API for
    (reverse-)geocoding. Not only is Nominatim a completely open
    service, it is also has a lot more data to offer.
  - GeoIP server and client API. WARNING: These will soon be
    removed in favor of geoclue2 so do not use them in your
    application. Instead use geoclue2 directly.
  - More test cases.
  - Various fixes to build and installation.
- Add pkgconfig(geoip) BuildRequires: new dependency.
* Fri Dec  9 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GeocodeGlib-1_0 subpackage.
- Add typelib-1_0-GeocodeGlib-1_0 Requires to devel subpackage.
* Fri Jun 17 2011 vuntz@opensuse.org
- Initial package (version 0.99.0).
